@@ -22,6 +22,7 @@
 #include "controlpanel.h"
 #include "outputconfig.h"
 #include "unifiedoutputconfig.h"
+#include "debug.h"
 
 #include <QVBoxLayout>
 
@@ -64,8 +65,10 @@ void ControlPanel::setConfig(const KScreen::ConfigPtr &config)
 
 void ControlPanel::addOutput(const KScreen::OutputPtr &output)
 {
-    OutputConfig *outputCfg = new OutputConfig(output, this);
+    OutputConfig *outputCfg = new OutputConfig(this);
     outputCfg->setVisible(false);
+    outputCfg->setShowScaleOption(mConfig->supportedFeatures().testFlag(KScreen::Config::Feature::PerOutputScaling));
+    outputCfg->setOutput(output);
     connect(outputCfg, &OutputConfig::changed,
             this, &ControlPanel::changed);
 
@@ -91,7 +94,7 @@ void ControlPanel::activateOutput(const KScreen::OutputPtr &output)
         return;
     }
 
-    qDebug() << "Activate output" << output->id();
+    qCDebug(KSCREEN_KCM) << "Activate output" << output->id();
 
     Q_FOREACH (OutputConfig *cfg, mOutputConfigs) {
         cfg->setVisible(cfg->output()->id() == output->id());
