@@ -79,6 +79,8 @@ Widget::Widget(QWidget *parent):
     widget->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
 
     QVBoxLayout *vbox = new QVBoxLayout(widget);
+    const int topMargin = style()->pixelMetric(QStyle::PM_LayoutTopMargin, 0, this);
+    vbox->setContentsMargins(0, topMargin, 0, 0);
     widget->setLayout(vbox);
 
     QHBoxLayout *hbox = new QHBoxLayout;
@@ -117,15 +119,16 @@ Widget::Widget(QWidget *parent):
 
     vbox->addWidget(mUnifyButton);
 
-    auto setScaleButton = new QPushButton(i18n("Scale Display"), this);
-    connect(setScaleButton, &QPushButton::released,
+    mScaleAllOutputsButton = new QPushButton(i18n("Scale Display"), this);
+    connect(mScaleAllOutputsButton, &QPushButton::released,
             [this] {
                 QPointer<ScalingConfig> dialog = new ScalingConfig(mConfig->outputs(), this);
                 dialog->exec();
                 delete dialog;
             });
-    
-    vbox->addWidget(setScaleButton);
+
+    vbox->addWidget(mScaleAllOutputsButton);
+
 
     mOutputTimer = new QTimer(this);
     connect(mOutputTimer, &QTimer::timeout,
@@ -171,6 +174,9 @@ void Widget::setConfig(const KScreen::ConfigPtr &config)
     mScreen->setConfig(mConfig);
     mControlPanel->setConfig(mConfig);
     mPrimaryCombo->setConfig(mConfig);
+    mUnifyButton->setEnabled(mConfig->outputs().count() > 1);
+    mScaleAllOutputsButton->setVisible(!mConfig->supportedFeatures().testFlag(KScreen::Config::Feature::PerOutputScaling));
+
 
     for (const KScreen::OutputPtr &output : mConfig->outputs()) {
         connect(output.data(), &KScreen::Output::isEnabledChanged,
